"""
This module will help to perform CRUD operations with Postgres databases
"""

import psycopg2
from dotenv import load_dotenv
import os
import logging

load_dotenv()

def connection(database):
    """
    Create a session with a given database and return a new connection object.


    :param str database: the name of the database that will be used as prefix to get its credentials

    :returns: connection object
    :rtype: connection

    """

    dbname = os.getenv(f'{database}_dbname')
    user = os.getenv(f'{database}_user')
    password = os.getenv(f'{database}_password')
    host = os.getenv(f'{database}_host')
    port = os.getenv(f'{database}_port')

    return psycopg2.connect(dbname=dbname, user=user, password=password, host=host, port=port)



def query(database, sql_query) -> list:
    """
    Run a query against a database then returns it's result as a list


    :param str database: the name of the database that will be used as prefix to get its credentials
    :param str sql_query: The sql query that will be executed

    :returns: a list of records
    :rtype: list

    """
    try:
        conn = connection(database)
        cursor = conn.cursor()
        cursor.execute(sql_query)
        data = cursor.fetchall()

    except (Exception, psycopg2.Error) as error:
        logging.error(f'Error while executing query on {database} database', error)

    finally:
        if conn:
            cursor.close()
            conn.close()
            logging.info(f'The connection to {database} database is now closed')

    return data






# -*- coding: utf-8 -*-

# Learn more: https://github.com/senseibara/propersandwich

import pathlib
from setuptools import setup, find_packages


readme = pathlib.Path('README.md').read_text()
license = pathlib.Path('LICENSE').read_text()

setup(
    name='propersandwich',
    version='0.1.0',
    description='propersandwich package',
    long_description=readme,
    author='Senseibara',
    author_email='ndiayebara93@gmail.com',
    url='https://github.com/senseibara/propersandwich',
    license=license,
    packages=find_packages(exclude=('tests', 'docs'))
)




"""
This module will help to perform CRUD operations with Google spreadsheets
"""

import pygsheets
import logging
import pandas as pd
import os
from dotenv import load_dotenv

# Load Environment variables
load_dotenv()


def create_worksheet(spreadsheet_url, worksheet_title):
    """
    Create a worksheet in an existing spreadsheet


    :param str spreadsheet_url: The Environment variable containing the URL of the spreadsheet
    :param str worksheet_title: The title of the worksheet

    """

    # Create a client
    google_sheet_client = pygsheets.authorize(service_account_env_var='GOOGLE_API')

    # Open the sheet
    spreadsheet = google_sheet_client.open_by_url(os.getenv(spreadsheet_url))

    # Create a new worksheet
    spreadsheet.add_worksheet(worksheet_title)


def read_worksheet(spreadsheet_url, worksheet_title, start='A1') -> pd.DataFrame:
    """
    Read a worksheet and return it's content as a Dataframe


    :param str spreadsheet_url: The Environment variable containing the URL of the spreadsheet
    :param str worksheet_title: The title of the worksheet
    :param str start: op left cell to load into data frame. (default: A1)

    :returns: The content of the tab
    :rtype: dataframe

    """

    # Create a client
    google_sheet_client = pygsheets.authorize(service_account_env_var='GOOGLE_API')

    # Open the sheet
    spreadsheet = google_sheet_client.open_by_url(os.getenv(spreadsheet_url))

    # Select the worksheet
    worksheet = spreadsheet.worksheet_by_title(worksheet_title)

    # Get the content of this worksheet as a pandas data frame.
    data = worksheet.get_as_df(start=start)

    logging.info(f"Retrieved {len(data.index)} rows from [ {worksheet.title} / {spreadsheet.title} ]")

    return data


def delete_worksheet(spreadsheet_url, worksheet_title):
    """
    Delete a worksheet in an existing spreadsheet


    :param str spreadsheet_url: The Environment variable containing the URL of the spreadsheet
    :param str worksheet_title: The title of the worksheet

    """

    # Create a client
    google_sheet_client = pygsheets.authorize(service_account_env_var='GOOGLE_API')

    # Open the sheet
    spreadsheet = google_sheet_client.open_by_url(os.getenv(spreadsheet_url))

    # Select the worksheet
    worksheet = spreadsheet.worksheet_by_title(worksheet_title)

    # Delete a worksheet by title
    spreadsheet.del_worksheet(worksheet)


